@@ -16,7 +16,7 @@ class DropCapabilities(BaseK8Check):
         super().__init__(name=name, id=id, categories=categories, supported_entities=supported_kind)
 
     def get_resource_id(self, conf):
-        return conf['parent']
+        return f'{conf["parent"]} - {conf["name"]}'
 
     def scan_spec_conf(self, conf):
         if "securityContext" in conf:
@@ -27,4 +27,5 @@ class DropCapabilities(BaseK8Check):
                             return CheckResult.PASSED
         return CheckResult.FAILED
 
-check = DropCapabilities()
\ No newline at end of file
+
+check = DropCapabilities()
