@@ -22,14 +22,9 @@ class LaunchConfigurationEBSEncryption(BaseResourceValueCheck):
         """
         for key in conf.keys():
             if "block_device" in key and "ephemeral" not in key:
-                if "encrypted" in conf[key][0]:
-                    if conf[key][0]["encrypted"] == [False]:
-                        return CheckResult.FAILED
-                    else:
-                        return CheckResult.PASSED
-                else:
+                if isinstance(conf[key][0], dict) and conf[key][0].get("encrypted") != [True]:
                     return CheckResult.FAILED
-        return CheckResult.FAILED
+        return CheckResult.PASSED
 
 
 check = LaunchConfigurationEBSEncryption()
